@@ -31,7 +31,6 @@
 
 #include "gdu-time-label.h"
 #include "gdu-ata-smart-dialog.h"
-#include "gdu-spinner.h"
 #include "gdu-pool-tree-model.h"
 #include "gdu-details-table.h"
 #include "gdu-details-element.h"
@@ -1090,6 +1089,8 @@ on_self_test_button_clicked (GduButtonElement *button_element,
 {
         GduAtaSmartDialog *dialog = GDU_ATA_SMART_DIALOG (user_data);
         GtkWidget *test_dialog;
+        GtkWidget *content_area;
+        GtkWidget *action_area;
         GtkWidget *hbox;
         GtkWidget *image;
         GtkWidget *main_vbox;
@@ -1108,25 +1109,29 @@ on_self_test_button_clicked (GduButtonElement *button_element,
 
         test_dialog = gtk_dialog_new_with_buttons (NULL,
                                                    GTK_WINDOW (dialog),
-                                                   GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT|GTK_DIALOG_NO_SEPARATOR,
+                                                   GTK_DIALOG_MODAL|GTK_DIALOG_DESTROY_WITH_PARENT,
                                                    NULL);
         gtk_window_set_title (GTK_WINDOW (test_dialog), "");
 
+
+	content_area = gtk_dialog_get_content_area (GTK_DIALOG (test_dialog));
+	action_area = gtk_dialog_get_action_area (GTK_DIALOG (test_dialog));
+
 	gtk_container_set_border_width (GTK_CONTAINER (test_dialog), 6);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (test_dialog)->vbox), 2);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (test_dialog)->action_area), 5);
-	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (test_dialog)->action_area), 6);
+	gtk_box_set_spacing (GTK_BOX (content_area), 2);
+	gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
+	gtk_box_set_spacing (GTK_BOX (action_area), 6);
 	gtk_window_set_resizable (GTK_WINDOW (test_dialog), FALSE);
 
-	hbox = gtk_hbox_new (FALSE, 12);
+	hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
 	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (test_dialog)->vbox), hbox, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 
 	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
 	gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
 	gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-	main_vbox = gtk_vbox_new (FALSE, 10);
+	main_vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 10);
 	gtk_box_pack_start (GTK_BOX (hbox), main_vbox, TRUE, TRUE, 0);
 
 	label = gtk_label_new (NULL);
@@ -1267,15 +1272,13 @@ gdu_ata_smart_dialog_constructed (GObject *object)
         g_free (vpd_name);
         g_free (name);
 
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
-
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
 
         align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
         gtk_alignment_set_padding (GTK_ALIGNMENT (align), 12, 12, 12, 12);
         gtk_box_pack_start (GTK_BOX (content_area), align, TRUE, TRUE, 0);
 
-        vbox = gtk_vbox_new (FALSE, 12);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
         gtk_container_add (GTK_CONTAINER (align), vbox);
 
         /* ---------------------------------------------------------------------------------------------------- */
