@@ -283,6 +283,7 @@ gdu_edit_linux_lvm2_dialog_constructed (GObject *object)
         GduEditLinuxLvm2Dialog *dialog = GDU_EDIT_LINUX_LVM2_DIALOG (object);
         GduLinuxLvm2VolumeGroup *vg;
         GtkWidget *content_area;
+        GtkWidget *action_area;
         GtkWidget *vbox;
         GtkWidget *vbox2;
         GtkWidget *hbox;
@@ -310,21 +311,21 @@ gdu_edit_linux_lvm2_dialog_constructed (GObject *object)
         content_area = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
         gtk_container_set_border_width (GTK_CONTAINER (content_area), 10);
 
-        hbox = gtk_hbox_new (FALSE, 12);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 12);
         gtk_box_pack_start (GTK_BOX (content_area), hbox, TRUE, TRUE, 0);
 
         image = gtk_image_new_from_gicon (icon, GTK_ICON_SIZE_DIALOG);
         gtk_misc_set_alignment (GTK_MISC (image), 0.5, 0.0);
         gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
 
-        vbox = gtk_vbox_new (FALSE, 6);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
         gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
-        gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+        action_area = gtk_dialog_get_action_area (GTK_DIALOG (dialog));
         gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->vbox), 0);
-        gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dialog)->action_area), 5);
-        gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dialog)->action_area), 6);
+        gtk_box_set_spacing (GTK_BOX (content_area), 0);
+        gtk_container_set_border_width (GTK_CONTAINER (action_area), 5);
+        gtk_box_set_spacing (GTK_BOX (action_area), 6);
 
         name = gdu_presentable_get_name (GDU_PRESENTABLE (vg));
         vpd_name = gdu_presentable_get_vpd_name (GDU_PRESENTABLE (vg));
@@ -344,7 +345,7 @@ gdu_edit_linux_lvm2_dialog_constructed (GObject *object)
         g_free (s);
         gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
-        vbox2 = gtk_vbox_new (FALSE, 12);
+        vbox2 = gtk_box_new (GTK_ORIENTATION_VERTICAL, 12);
         align = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
         gtk_alignment_set_padding (GTK_ALIGNMENT (align), 6, 0, 12, 0);
         gtk_box_pack_start (GTK_BOX (vbox), align, TRUE, TRUE, 0);
