@@ -86,7 +86,7 @@ gdu_unit_get_name (GduUnit unit)
 
         switch (unit) {
         case GDU_UNIT_KB:
-                ret = _("KB");
+                ret = _("kB");
                 break;
         default:
                 g_warning ("Unknown unit %d", unit);
@@ -124,7 +124,7 @@ gdu_unit_guess (const gchar *str)
 
         ret = GDU_UNIT_NOT_SET;
 
-        if (strstr (str, "KB") != NULL) {
+        if (strstr (str, "kB") != NULL) {
                 ret = GDU_UNIT_KB;
         } else if (strstr (str, "MB") != NULL) {
                 ret = GDU_UNIT_MB;
@@ -172,7 +172,7 @@ enum
 
 guint signals[LAST_SIGNAL] = {0,};
 
-G_DEFINE_TYPE (GduSizeWidget, gdu_size_widget, GTK_TYPE_HBOX)
+G_DEFINE_TYPE (GduSizeWidget, gdu_size_widget, GTK_TYPE_BOX)
 
 static void update_stepping (GduSizeWidget *widget);
 
