@@ -481,12 +481,12 @@ on_smart_button_clicked (GduButtonElement *button_element,
                          gpointer          user_data)
 {
         GduSectionDrive *section = GDU_SECTION_DRIVE (user_data);
-        GtkWindow *toplevel;
         GtkWidget *dialog;
 
-        toplevel = GTK_WINDOW (gdu_shell_get_toplevel (gdu_section_get_shell (GDU_SECTION (section))));
-        dialog = gdu_ata_smart_dialog_new (toplevel,
+        dialog = gdu_ata_smart_dialog_new (NULL,
                                            GDU_DRIVE (gdu_section_get_presentable (GDU_SECTION (section))));
+        gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
+
         gtk_widget_show_all (dialog);
         gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
@@ -497,12 +497,11 @@ gdu_section_drive_on_benchmark_button_clicked (GduButtonElement *button_element,
                                                gpointer          user_data)
 {
         GduSection *section = GDU_SECTION (user_data);
-        GtkWindow *toplevel;
         GtkWidget *dialog;
 
-        toplevel = GTK_WINDOW (gdu_shell_get_toplevel (gdu_section_get_shell (GDU_SECTION (section))));
-        dialog = gdu_drive_benchmark_dialog_new (toplevel,
+        dialog = gdu_drive_benchmark_dialog_new (NULL,
                                                  GDU_DRIVE (gdu_section_get_presentable (GDU_SECTION (section))));
+        gtk_dialog_add_button (GTK_DIALOG (dialog), GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE);
         gtk_widget_show_all (dialog);
         gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
@@ -830,7 +829,7 @@ gdu_section_drive_constructed (GObject *object)
 
         info_bar = gtk_info_bar_new ();
         gtk_info_bar_set_message_type (GTK_INFO_BAR (info_bar), GTK_MESSAGE_WARNING);
-        hbox = gtk_hbox_new (FALSE, 6);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_WARNING, GTK_ICON_SIZE_DIALOG);
         gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
         label = gtk_label_new (NULL);
@@ -856,7 +855,7 @@ gdu_section_drive_constructed (GObject *object)
                           "response",
                           G_CALLBACK (on_multipath_component_info_bar_go_to_multipath_device),
                           section);
-        hbox = gtk_hbox_new (FALSE, 6);
+        hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
         image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
         gtk_box_pack_start (GTK_BOX (hbox), image, FALSE, FALSE, 0);
         label = gtk_label_new (NULL);
@@ -882,7 +881,7 @@ gdu_section_drive_constructed (GObject *object)
         gtk_alignment_set_padding (GTK_ALIGNMENT (align), 0, 0, 12, 0);
         gtk_box_pack_start (GTK_BOX (section), align, FALSE, FALSE, 0);
 
-        vbox = gtk_vbox_new (FALSE, 6);
+        vbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
         gtk_container_add (GTK_CONTAINER (align), vbox);
         section->priv->main_vbox = vbox;
 
